OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Hozzáadva a kedvencekhez",
    "Removed from favorites" : "Eltávolítva a kedvencekből",
    "You added {file} to your favorites" : "Hozzáadta a kedvencekhez: {file}",
    "You removed {file} from your favorites" : "Eltávolította a kedvencek közül: {file}",
    "Favorites" : "Kedvencek",
    "File changes" : "Fájlváltozások",
    "Created by {user}" : "Létrehozta: {user}",
    "Changed by {user}" : "Módosította: {user}",
    "Deleted by {user}" : "Törölte: {user}",
    "Restored by {user}" : "Helyreállította: {user}",
    "Renamed by {user}" : "Átnevezte: {user}",
    "Moved by {user}" : "Áthelyezte: {user}",
    "\"remote account\"" : "„távoli fiók”",
    "You created {file}" : "Létrehozta: {file}",
    "You created an encrypted file in {file}" : "Létrehozott egy titkosított fájlt ebben: {file}",
    "{user} created {file}" : "{user} létrehozta: {file}",
    "{user} created an encrypted file in {file}" : "{user} létrehozott egy titkosított fájlt ebben: {file}",
    "{file} was created in a public folder" : "{file} létrehozva egy nyilvános mappában",
    "You changed {file}" : "Módosította: {file}",
    "You changed an encrypted file in {file}" : "Módosított egy titkosított fájlt ebben: {file}",
    "{user} changed {file}" : "{user} módosította: {file}",
    "{user} changed an encrypted file in {file}" : "{user} módosított egy titkosított fájlt ebben: {file}",
    "You deleted {file}" : "Törölte: {file}",
    "You deleted an encrypted file in {file}" : "Törölt egy titkosított fájlt itt: {file}",
    "{user} deleted {file}" : "{user} törölte: {file}",
    "{user} deleted an encrypted file in {file}" : "{user} törölt egy titkosított fájlt itt: {file}",
    "You restored {file}" : "Helyreállította: {file}",
    "{user} restored {file}" : "{user} helyreállította: {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Átnevezte a(z) {oldfile} (rejtett) fájlt a következőre: {newfile} (rejtett)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Átnevezte a(z) {oldfile} (rejtett) fájlt erre: {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Átnevezte a(z) {oldfile} fájlt erre: {newfile} (rejtett)",
    "You renamed {oldfile} to {newfile}" : "Átnevezte a(z) {oldfile} fájlt erre: {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} átnevezte a(z) {oldfile} (rejtett) fájlt erre: {newfile} (rejtett)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} átnevezte a(z) {oldfile} (rejtett) fájlt a következőre: {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} átnevezte a(z) {oldfile} fájlt a következőre: {newfile} (rejtett)",
    "{user} renamed {oldfile} to {newfile}" : "{user} átnevezte a(z) {oldfile} fájlt erre: {newfile}",
    "You moved {oldfile} to {newfile}" : "Áthelyezte a(z) {oldfile} fájlt ide: {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} áthelyezte a(z) {oldfile} fájlt ide: {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Egy fájl eltávolítva vagy hozzáadva a <strong>kedvencekhez</strong>",
    "Files" : "Fájlok",
    "A file or folder has been <strong>changed</strong>" : "Egy fájl vagy mappa <strong>megváltozott</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Egy kedvenc fájl vagy mappa <strong> megváltozott</strong>",
    "Failed to authorize" : "Sikertelen hitelesítés",
    "Invalid folder path" : "Érvénytelen mappaútvonal",
    "Folder not found" : "A mappa nem található",
    "The file cannot be found" : "A fájl nem található",
    "The destination path does not exist: %1$s" : "Az elérési útvonal nem létezik: %1$s",
    "You do not have permission to create a file at the specified location" : "Nincs jogosultsága fájl létrehozására a megadott helyen",
    "The file could not be converted." : "A fájl nem alakítható át.",
    "Could not get relative path to converted file" : "Nem sikerült lekérni az átalakított fájl relatív elérési útját",
    "Limit must be a positive integer." : "A korlátnak pozitív egésznek kell lennie.",
    "The replacement character may only be a single character." : "A cserekarakter csak egyetlen karakter lehet.",
    "Filename sanitization already started." : "A fájlnévtisztítás más elindult.",
    "No filename sanitization in progress." : "Nincs folyamatban fájlnévtisztítás.",
    "Favorite files" : "Kedvenc fájlok",
    "No favorites" : "Nincsenek kedvencek",
    "More favorites" : "További kedvencek",
    "Accept" : "Elfogadás",
    "Reject" : "Elutasítás",
    "Incoming ownership transfer from {user}" : "Bejövő tulajdonjog-átruházás {user} részéről",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Elfogadja a(z) {path} útvonalat?\n\nMegjegyzés: Az átruházási folyamat akár 1 órát is igénybe vehet az elfogadás után.",
    "Ownership transfer denied" : "Tulajdonjog átadása visszautasítva",
    "Your ownership transfer of {path} was denied by {user}." : "A(z) {path} tulajdonjogának átadását {user} visszautasította.",
    "Ownership transfer failed" : "Tulajdonjog átadása sikertelen",
    "Your ownership transfer of {path} to {user} failed." : "A(z) {path} tulajdonjogának átruházása {user} számára sikertelen.",
    "The ownership transfer of {path} from {user} failed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikertelen.",
    "Ownership transfer done" : "Tulajdonjog átruházása kész",
    "Your ownership transfer of {path} to {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} számára befejeződött.",
    "The ownership transfer of {path} from {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikeres.",
    "in %s" : "itt:  %s",
    "Transferred from %1$s on %2$s" : "Átadva tőle: %1$s, ekkor %2$s",
    "File Management" : "Fájlkezelés",
    "Home" : "Saját mappa",
    "Target folder does not exist any more" : "A célmappa már nem létezik",
    "Reload current directory" : "Jelenlegi könyvtár újratöltése",
    "Go to the \"{dir}\" directory" : "Ugrás a(z) „{dir}” könyvtárhoz",
    "Current directory path" : "Jelenlegi könyvtár útvonala",
    "Share" : "Megosztás",
    "Your have used your space quota and cannot upload files anymore" : "Már felhasználta a tárhelykvótáját, így már nem tölthet fel fájlokat",
    "You do not have permission to upload or create files here." : "Nincs jogosultsága, hogy fájlokat töltsön fel és hozzon létre itt.",
    "Drag and drop files here to upload" : "Húzza ide a fájlokat a feltöltéshez",
    "Favorite" : "Kedvenc",
    "Back" : "Vissza",
    "Toggle selection for file \"{displayName}\"" : "„{displayName}” fájl kijelölésének átváltása",
    "Toggle selection for folder \"{displayName}\"" : "„{displayName}” mappa kijelölésének átváltása",
    "File is loading" : "A fájl épp betöltődik",
    "Folder is loading" : "A mappa épp betöltődik",
    "Filename" : "Fájlnév",
    "Folder name" : "Mappanév",
    "This node is unavailable" : "Ez az elem nem érhető el",
    "Another entry with the same name already exists." : "Már létezik ilyen nevű bejegyzés.",
    "Invalid filename." : "Érvénytelen fájlnév.",
    "Rename file" : "Fájl átnevezése",
    "Folder" : "Mappa",
    "Unknown file type" : "Ismeretlen fájltípus",
    "{ext} image" : "{ext}-kép",
    "{ext} video" : "{ext}-videó",
    "{ext} audio" : "{ext}-hang",
    "{ext} text" : "{ext}-szöveg",
    "Pending" : "Függőben",
    "Unknown date" : "Ismeretlen dátum",
    "Active filters" : "Aktív szűrők",
    "Remove filter" : "Szűrő eltávolítása",
    "Today" : "Ma",
    "Last 7 days" : "Előző 7 nap",
    "Last 30 days" : "Előző 30 nap",
    "This year ({year})" : "Idén ({year})",
    "Last year ({year})" : "Tavaly ({year})",
    "Custom date range" : "Egyéni dátumtartomány",
    "Search everywhere" : "Keresés mindenhol",
    "Documents" : "Dokumentumok",
    "Spreadsheets" : "Munkafüzetek",
    "Presentations" : "Bemutatók",
    "PDFs" : "PDF-ek",
    "Folders" : "Mappák",
    "Audio" : "Hangok",
    "Images" : "Képek",
    "Videos" : "Videók",
    "Filters" : "Szűrők",
    "Appearance" : "Megjelenés",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "Show file type column" : "Fájltípus oszlop megjelenítése",
    "Show file extensions" : "Fájlkiterjesztések megjelenítése",
    "Crop image previews" : "Kép előnézetek vágása",
    "General" : "Általános",
    "Sort favorites first" : "Kedvencek előre rendezése",
    "Sort folders before files" : "Mappák fájlok elé rendezése",
    "Enable folder tree view" : "Mappafanézet engedélyezése",
    "Default view" : "Alapértelmezett nézet",
    "All files" : "Összes fájl",
    "Personal files" : "Személyes fájlok",
    "Additional settings" : "További beállítások",
    "Actions" : "Műveletek",
    "File actions" : "Fájlműveletek",
    "Selection" : "Kijelölés",
    "Select all files" : "Összes fájl kijelölése",
    "Deselect all" : "Kijelölés megszüntetése",
    "Select or deselect" : "Kijelölés vagy annak megszüntetése",
    "Select a range" : "Válasszon tartományt",
    "Navigation" : "Navigáció",
    "Go to parent folder" : "Ugrás a szülőmappához",
    "Go to file above" : "Ugrás a fentebbi fájlhoz",
    "Go to file below" : "Ugrás a lentebbi fájlhoz",
    "Go left in grid" : "Balra ugrás a rácsban",
    "Go right in grid" : "Jobbra ugrás a rácsban",
    "View" : "Nézet",
    "Toggle grid view" : "Rácsnézet be/ki",
    "Show those shortcuts" : "Gyorsbillentyűk megjelenítése",
    "Warnings" : "Figyelmeztetések",
    "Warn before changing a file extension" : "Figyelmeztetés a fájlkiterjesztés módosítása előtt",
    "Warn before deleting a file" : "Figyelmeztetés fájl törlése előtt",
    "WebDAV URL" : "WebDAV-webcím",
    "Create an app password" : "Alkalmazásjelszó létrehozása",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "A WebDAV-hitelesítéshez szükséges, mert a Kétlépcsős hitelesítés engedélyezve van ennél a fióknál.",
    "How to access files using WebDAV" : "Hogyan érje el a fájlokat WebDAV-val",
    "Total rows summary" : "Összes sor összegzése",
    "Toggle selection for all files and folders" : "Minden fájl és mappa kijelölésének átváltása",
    "Name" : "Név",
    "File type" : "Fájltípus",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "{displayName}: failed on some elements" : "{displayName}: egyes elemeken sikertelen",
    "{displayName}: done" : "{displayName}: kész",
    "{displayName}: failed" : "{displayName}: sikertelen",
    "(selected)" : "(kiválasztva)",
    "List of files and folders." : "Fájlok és mappák felsorolása.",
    "You have used your space quota and cannot upload files anymore." : "Már felhasználta a tárhelykvótáját, így már nem tölthet fel fájlokat.",
    "Column headers with buttons are sortable." : "A gombot tartalmazó oszlopfejlécek rendezhetők.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ez a lista teljesítménybeli okokból nincs teljes egészében megjelenítve. A fájlok a listában navigálás során jelennek meg.",
    "File not found" : "A fájl nem található",
    "_{count} selected_::_{count} selected_" : ["{count} kijelölve","{count} kijelölve"],
    "Search everywhere …" : "Keresés mindenhol…",
    "Search here …" : "Keresés itt…",
    "Search scope options" : "Keresési hatókör beállításai",
    "Search here" : "Keresés itt",
    "Owner" : "Tulajdonos",
    "{usedQuotaByte} used" : "{usedQuotaByte} felhasználva",
    "{used} of {quota} used" : "{used} / {quota} felhasználva",
    "{relative}% used" : "{relative}% felhasználva",
    "Could not refresh storage stats" : "Nem sikerült frissíteni a tárhelystatisztikákat",
    "Your storage is full, files can not be updated or synced anymore!" : "A tárhelye megtelt, a fájlok többé nem frissíthetők vagy szinkronizálhatók.",
    "Storage information" : "Tárhely-információ",
    "Storage quota" : "Tárhelykvóta",
    "New folder" : "Új mappa",
    "Create new folder" : "Új mappa létrehozása",
    "This name is already in use." : "Ez a név már foglalt.",
    "Create" : "Létrehozás",
    "Files starting with a dot are hidden by default" : "A ponttal kezdődő fájlok alapértelmezetten el vannak rejtve",
    "Failed to start filename sanitization." : "Nem sikerült a fájlnévtisztítás elindítása.",
    "Failed to refresh filename sanitization status." : "Nem sikerült a fájlnévtisztítás állapotának frissítése.",
    "Filename sanitization in progress." : "Fájlnévtisztítás folyamatban.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Jelenleg {processedUsers} / {totalUsers} fiók van már feldolgozva.",
    "Preparing …" : "Előkészítés…",
    "Refresh" : "Frissítés",
    "All files have been santized for Windows filename support." : "Az összes fájlnév meg lett tisztítva a windowsos fájlnevek támogatásához.",
    "Some files could not be sanitized, please check your logs." : "Egyes fájlok tisztítása nem sikerült, ellenőrizze a naplókat.",
    "Sanitization errors" : "Tisztítási hibák",
    "Not sanitized filenames" : "Nem megtisztított fájlnevek",
    "Windows filename support has been enabled." : "A windowsos fájlnevek támogatása engedélyezve lett.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Bár ez megtiltja, hogy a felhasználók nem támogatott nevű fájlokat hozzanak létre, a meglévő fájlok nem lesznek átnevezve, így Windowson továbbra is hibás lehet a szinkronizálás.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Átneveztetheti az érvénytelen fájlnevű fájlokat, ez egy háttérfeladatban lesz végrehajtva, és eltarthat egy ideig.",
    "Please note that this may cause high workload on the sync clients." : "Vegye figyelembe, hogy ez magas terhelést okozhat a szinkronizálási klienseken.",
    "Limit" : "Korlát",
    "This allows to configure how many users should be processed in one background job run." : "Ez lehetővé teszi, hogy beállítsa, hány felhasználó legyen feldolgozva egyetlen háttérfeladatban.",
    "Sanitize filenames" : "Fájlnevek tisztítása",
    "(starting)" : "(indítás)",
    "Fill template fields" : "Töltse ki a sablon mezőit",
    "Submitting fields …" : "Mezők beküldése…",
    "Submit" : "Beküldés",
    "Choose a file or folder to transfer" : "Válassz egy átruházandó fájlt vagy mappát",
    "Transfer" : "Átruházás",
    "Transfer {path} to {userid}" : "{path} átruházása {userid} számára",
    "Invalid path selected" : "Érvénytelen útvonal kiválasztva",
    "Unknown error" : "Ismeretlen hiba",
    "Ownership transfer request sent" : "Tulajdonjog átruházási kérés elküldve",
    "Cannot transfer ownership of a file or folder you do not own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
    "Transfer ownership of a file or folder" : "Fájl vagy mappa tulajdonjogának átruházása",
    "Choose file or folder to transfer" : "Válasszon egy fájlt vagy mappát az átruházáshoz",
    "Change" : "Módosítás",
    "New owner" : "Új tulajdonos",
    "Keep {old}" : "{old} megtartása",
    "Keep without extension" : "Megtartás kiterjesztés nélkül",
    "Use {new}" : "{new} használata",
    "Remove extension" : "Kiterjesztés eltávolítása",
    "Change file extension" : "Kiterjesztés módosítása",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "A fájl „{old}” kiterjesztésről „{new}” kiterjesztésre változtatása olvashatatlanná teheti azt.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "A fájl „{old}” kiterjesztésének eltávolítása olvashatatlanná teheti azt.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "A fájl „{new}” kiterjesztésének hozzáadása olvashatatlanná teheti azt.",
    "Do not show this dialog again." : "Ne jelenítse meg újra ezt a párbeszédablakot.",
    "Cancel" : "Mégse",
    "Rename" : "Átnevezés",
    "Select file or folder to link to" : "Válassza ki a hivatkozandó fájlt vagy mappát",
    "Choose {file}" : "{file} kiválasztása",
    "Files settings" : "Fájlok beállításai",
    "Switch to list view" : "Váltás listanézetre",
    "Switch to grid view" : "Váltás rácsnézetre",
    "The file could not be found" : "A fájl nem található",
    "Upload was cancelled by user" : "Feltöltés megszakítva a felhasználó által",
    "Not enough free space" : "Nincs elég szabad hely",
    "Operation is blocked by access control" : "A hozzáférés-vezérlés letiltotta a műveletet",
    "Error during upload: {message}" : "Hiba a feltöltés során: {message}",
    "Error during upload, status code {status}" : "Hiba a feltöltés közben, állapotkód: {status}",
    "Unknown error during upload" : "Ismeretlen hiba a feltöltés során",
    "Loading current folder" : "Jelenlegi mappa betöltése",
    "Retry" : "Újra",
    "No files in here" : "Itt nincsenek fájlok",
    "Upload some content or sync with your devices!" : "Töltsön fel néhány tartalmat, vagy szinkronizáljon az eszközeivel.",
    "Go back" : "Visszalépés",
    "Views" : "Nézetek",
    "Loading …" : "Betöltés…",
    "Your files" : "Saját fájlok",
    "Open in files" : "Megnyitás a fájlokban",
    "File cannot be accessed" : "A fájl nem érhető el",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "A fájl nem található, vagy nincs jogosultsága a megtekintéséhez. Kérje meg a feladót, hogy ossza meg.",
    "No search results for “{query}”" : "Nincs találat ehhez: „{query}”",
    "Search for files" : "Fájlok keresése",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Fájlnevek korlátozásának engedélyezése, amely biztosítja, hogy a fájlok szinkronizálhatók legyenek az összes klienssel. Alapállapotban az összes fájlnév engedélyezett, amely a POSIX (mint a Linux vagy a macOS) rendszereken érvényes.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "A Windows-kompatibilis fájlnevek engedélyezése után a meglévő fájlok már nem módosíthatóak, de a tulajdonosaik átnevezhetik őket érvényes új fájlnevekre.",
    "Failed to toggle Windows filename support" : "Nem sikerült a windowsos fájlnevek támogatásának átkapcsolása.",
    "Files compatibility" : "Fájlok kompatibilitása",
    "Enforce Windows compatibility" : "Windows-kompatibilitás kényszerítése",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ez megakadályozza a Windows rendszereken érvénytelen fájlneveket, mint például a foglalt neveket vagy a speciális karaktereket. De ez nem fogja érvényesíteni a kis- és nagybetűk egyezőnek tekintését.",
    "Blank" : "Üres",
    "Unable to create new file from template" : "Nem lehet új fájlt létrehozni a sablonból",
    "Pick a template for {name}" : "Válassz sablont a(z) {name} fájlnak",
    "Create a new file with the selected template" : "Új fájl létrehozása a kiválasztott sablonnal",
    "Creating file" : "Fájl létrehozása",
    "Save as {displayName}" : "Mentés mint {displayName}",
    "Save as …" : "Mentés másként…",
    "Converting files …" : "Fájlok átalakítása…",
    "Failed to convert files: {message}" : "Nem sikerült a fájlok átalakítása: {message}",
    "All files failed to be converted" : "Az összes fájl átalakítása sikertelen",
    "One file could not be converted: {message}" : "Egy fájl nem alakítható át: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n fájl nem alakítható át","%n fájl nem alakítható át"],
    "_%n file converted_::_%n files converted_" : ["%n fájl átalakítva","%n fájl átalakítva"],
    "Files converted" : "Fájlok átalakítva",
    "Failed to convert files" : "Nem sikerült a fájlok átalakítása",
    "Converting file …" : "Fájl átalakítása…",
    "File successfully converted" : "Fájl sikeresen átalakítva",
    "Failed to convert file: {message}" : "Nem sikerült a fájl átalakítása: {message}",
    "Failed to convert file" : "Nem sikerült a fájl átalakítása",
    "Delete" : "Törlés",
    "Leave this share" : "Megosztás elhagyása",
    "Leave these shares" : "Megosztások elhagyása",
    "Disconnect storage" : "Tároló leválasztása",
    "Disconnect storages" : "Tárolók leválasztása",
    "Delete permanently" : "Végleges törlés",
    "Delete and unshare" : "Törlés és megosztás visszavonása",
    "Delete file" : "Fájl törlése",
    "Delete files" : "Fájlok törlése",
    "Delete folder" : "Mappa törlése",
    "Delete folders" : "Mappák törlése",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count} elem végleges törlésére készül","{count} elem végleges törlésére készül"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count} elem törlésére készül","{count} elem törlésére készül"],
    "Confirm deletion" : "Törlés megerősítése",
    "Download" : "Letöltés",
    "The requested file is not available." : "A kért fájl nem érhető el.",
    "The requested files are not available." : "A kért fájlok nem érhetőek el.",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add or remove favorite" : "Kedvenc hozzáadása vagy eltávolítása",
    "Move" : "Áthelyezés",
    "Copy" : "Másolás",
    "Move or copy" : "Áthelyezés vagy másolás",
    "Destination is not a folder" : "A cél nem mappa",
    "This file/folder is already in that directory" : "Ez a fájl/mappa már létezik a mappában",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "A fájl/mappa önmagába, vagy saját almappájába áthelyezése nem lehetséges",
    "A file or folder with that name already exists in this folder" : "Már létezik ilyen nevű fájl vagy mappa ebben a mappában",
    "The files are locked" : "A fájlok zárolva vannak",
    "The file does not exist anymore" : "Ez a fájl már nem létezik",
    "Moving \"{source}\" to \"{destination}\" …" : "A(z) „{source}” áthelyezése ide: „{destination}”…",
    "Copying \"{source}\" to \"{destination}\" …" : "A(z) „{source}” másolása ide: „{destination}”…",
    "Choose destination" : "Válasszon célt",
    "Copy to {target}" : "Másolás ide: {target}",
    "Move to {target}" : "Áthelyezés ide: {target}",
    "Move or copy operation failed" : "Nem sikerült az áthelyezés vagy a másolás",
    "Open folder" : "Mappa megnyitása",
    "Open folder {displayName}" : "A(z) {displayName} mappa megnyitása",
    "Open in Files" : "Megnyitás a Fájlokban",
    "Open locally" : "Megnyitás helyben",
    "Failed to redirect to client" : "Nem sikerült az átirányítás a klienshez",
    "Open file locally" : "A fájl megnyitása helyben",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "A fájlnak most már meg kellene nyílni az eszközén. Ha mégsem, ellenőrizze, hogy telepítve van-e az asztali alkalmazás.",
    "Retry and close" : "Újrapróbálás és bezárás",
    "Open online" : "Megnyitás online",
    "Details" : "Részletek",
    "Unfavorite" : "Nem kedvenc",
    "View in folder" : "Megtekintés mappában",
    "Type" : "Típus",
    "Created new folder \"{name}\"" : "Új „{name}” mappa létrehozva",
    "Unable to initialize the templates directory" : "A sablonkönyvtár előkészítése sikertelen",
    "Create templates folder" : "Sablonmappa létrehozása",
    "Templates" : "Sablonok",
    "New template folder" : "Új sablonmappa",
    "In folder" : "Könyvtárban",
    "Search in all files" : "Keresés az összes fájlban",
    "Search in folder: {folder}" : "Keresés a mappában: {folder}",
    "One of the dropped files could not be processed" : "Egy vagy több idehúzott fájl nem dolgozható fel",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "A böngészője nem támogatja a fájlrendszer API-t. Könyvtárak nem lesznek feltöltve.",
    "No files to upload" : "Nincsenek feltöltendő fájlok",
    "Unable to create the directory {directory}" : "Nem hozható létre a(z) {directory} könyvtár",
    "Some files could not be uploaded" : "Néhány fájlt nem lehet feltölteni",
    "Files uploaded successfully" : "Fájlok sikeresen feltöltve",
    "No files to process" : "Nincsenek feldolgozandó fájlok",
    "Files copied successfully" : "A fájlok másolása sikeres",
    "Files moved successfully" : "A fájlok áthelyezése sikeres",
    "Some files could not be copied" : "Néhány fájlt nem lehetett másolni",
    "Some files could not be moved" : "Néhány fájlt nem lehetett áthelyezni",
    "Conflicts resolution skipped" : "Konfliktusfeloldás kihagyva",
    "Upload cancelled" : "Feltöltés megszakítva",
    "Could not rename \"{oldName}\", it does not exist any more" : "A(z) „{oldName}” nem nevezhető át, mert már nem létezik",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "A(z) „{newName}” név már használatban van a(z) „{dir}” mappában. Válasszon másik nevet.",
    "Could not rename \"{oldName}\"" : "A(z) „{oldName}” nem nevezhető át",
    "This operation is forbidden" : "Ez a művelet tiltott",
    "This folder is unavailable, please try again later or contact the administration" : "Ez a mappa nem érhető el, próbálja újra később, vagy lépjen kapcsolatba a rendszergazdával",
    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
    "Unexpected error: {error}" : "Váratlan hiba: {error}",
    "_%n file_::_%n files_" : ["%n fájl","%n fájl"],
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n hidden_::_%n hidden_" : ["%n rejtett","%n rejtett"],
    "Filename must not be empty." : "A fájlnév nem lehet üres.",
    "\"{char}\" is not allowed inside a filename." : "„{char}” nem szerepelhet a fájlnévben.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "A(z) „{segment}” egy fenntartott név és fájlnevek esetén nem engedélyezett.",
    "\"{extension}\" is not an allowed filetype." : "A(z) „{extension}” nem engedélyezett fájltípus.",
    "Filenames must not end with \"{extension}\"." : "Fájlnév nem végződhet ezzel: „{extension}”.",
    "List of favorite files and folders." : "Kedvenc fájlok és mappák felsorolása.",
    "No favorites yet" : "Még nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találja meg",
    "List of your files and folders." : "Saját fájlok és mappák felsorolása.",
    "Folder tree" : "Mappafa",
    "List of your files and folders that are not shared." : "Meg nem osztott fájlok és mappák felsorolása.",
    "No personal files found" : "Nem találhatóak személyes fájlok",
    "Files that are not shared will show up here." : "A meg nem osztott fájlok itt fognak megjelenni.",
    "Recent" : "Legutóbbi",
    "List of recently modified files and folders." : "Közelmúltban módosított fájlok és mappák felsorolása.",
    "No recently modified files" : "Nincs a közelmúltban módosított fájl",
    "Files and folders you recently modified will show up here." : "Az Ön által módosított fájlok és mappák itt jelennek meg.",
    "Search" : "Keresés",
    "Search results within your files." : "Keresési találatok a fájljaiban.",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltölteni próbált fájlok mérete meghaladja a kiszolgálón megengedett legnagyobb méretet.",
    "%1$s (renamed)" : "%1$s (átnevezve)",
    "renamed file" : "átnevezett fájl",
    "Upload (max. %s)" : "Feltöltés (legfeljebb %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "A Windows-kompatibilis fájlnevek engedélyezése után a meglévő fájlok már nem módosíthatóak, de a tulajdonosaik átnevezhetik őket érvényes új nevekre.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Továbbá lehetséges a fájlok automatikus átköltöztetése is a beállítás engedélyezése után, kövesse az occ parancs dokumentációját.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "A(z) „{oldName}” átnevezve erre: „{newName}”",
    "Clear filter" : "Szűrő törlése",
    "\"{displayName}\" failed on some elements" : "A(z) „{displayName}” művelet egyes elemeken nem sikerült",
    "\"{displayName}\" batch action executed successfully" : "A(z) „{displayName}” tömeges művelet sikeresen végrehajtva",
    "\"{displayName}\" action failed" : "A(z) „{displayName}” művelet nem sikerült",
    "Submitting fields …" : "Mezők beküldése…",
    "Shared by link" : "Megosztva hivatkozással",
    "Shared" : "Megosztva",
    "\"{displayName}\" action executed successfully" : "A(z) „{displayName}” művelet sikeresen végrehajtva",
    "Filter file names …" : "Fájlnevek szűrése…",
    "Clipboard is not available" : "A vágólap nem érhető el",
    "WebDAV URL copied to clipboard" : "A WebDAV-cím a vágólapra másolva",
    "Enable the grid view" : "Rácsnézet engedélyezése",
    "Enable folder tree" : "Mappafa engedélyezése",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Másolás a vágólapra",
    "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ha engedélyezte a kétfaktoros hitelesítést, akkor kattintson ide, hogy létrehozzon egy új alkalmazásjelszót, és azt használja.",
    "Prevent warning dialogs from open or reenable them." : "Figyelmeztető párbeszédablakok megnyitásának megakadályozása vagy engedélyezése.",
    "Show a warning dialog when changing a file extension." : "Figyelmeztető párbeszédablakok megnyitása a fájlkiterjesztés módosításakor.",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Speed up your Files experience with these quick shortcuts." : "Gyorsítsa fel a fájlböngészést ezekkel a billentyűparancsokkal.",
    "Open the actions menu for a file" : "Nyissa meg a fájl műveletek menüjét",
    "Rename a file" : "Fájl átnevezése",
    "Delete a file" : "Fájl törlése",
    "Favorite or remove a file from favorites" : "Fájl hozzáadása vagy eltávolítása a kedvencek közül",
    "Manage tags for a file" : "Fájl címkéinek kezelése",
    "Deselect all files" : "Összes fájl kijelölésének törlése",
    "Select or deselect a file" : "Fájl kijelölése vagy kijelölés törlése",
    "Select a range of files" : "Válasszon ki fájlokat",
    "Navigate to the parent folder" : "Navigálás a szülőmappához",
    "Navigate to the file above" : "Navigálás a fentebbi fájlhoz",
    "Navigate to the file below" : "Navigálás a lentebbi fájlhoz",
    "Navigate to the file on the left (in grid mode)" : "Navigálás a balra lévő fájlhoz (rács módban)",
    "Navigate to the file on the right (in grid mode)" : "Navigálás a jobbra lévő fájlhoz (rács módban)",
    "Toggle the grid view" : "Rácsnézet be/ki",
    "Open the sidebar for a file" : "Oldalsáv megnyitása a fájlhoz",
    "You" : "Ön",
    "Shared multiple times with different people" : "Többször megosztva különböző személyekkel",
    "Unable to change the favorite state of the file" : "Nem lehet megváltoztatni a fájl kedvenc állapotát",
    "Error while loading the file data" : "Hiba történt a fájladatok betöltése közben",
    "Tags" : "Címkék",
    "Save as …" : "Mentés másként…",
    "Converting files …" : "Fájlok átalakítása…",
    "Converting file …" : "Fájl átalakítása…",
    "Deletion cancelled" : "Törlés megszakítva",
    "Edit locally" : "Szerkesztés helyileg",
    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” áthelyezése ide: „{destination}” …",
    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” másolása ide: „{destination}” …",
    "(copy)" : "(másolat)",
    "(copy %n)" : "(%n. másolat)",
    "Move cancelled" : "Áthelyezés megszakítva",
    "Cancelled move or copy of \"{filename}\"." : "A(z) „{filename}” áthelyezése vagy másolása megszakítva.",
    "Cancelled move or copy operation" : "Az áthelyezés vagy másolás művelet megszakítva",
    "Open details" : "Részletek megnyitása",
    "Photos and images" : "Fényképek és képek",
    "New folder creation cancelled" : "Az új mappa létrehozása megszakítva",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem érhető el, nézze meg a naplófájlokat vagy lépjen kapcsolatba az adminisztrátorral",
    "All folders" : "Összes mappa",
    "Open file sidebar" : "Fájl oldalsáv megnyitása",
    "Search everywhere …" : "Keresés mindenhol…",
    "Search here …" : "Keresés itt…",
    "Preparing …" : "Előkészítés…"
},
"nplurals=2; plural=(n != 1);");
